aboutsummaryrefslogtreecommitdiffstats
path: root/ram
diff options
context:
space:
mode:
authordannye <33dannye@gmail.com>2023-11-21 20:56:28 -0600
committerdannye <33dannye@gmail.com>2023-11-21 20:56:28 -0600
commit04f7f7f506a1dbb877e4678601261e8157fd0e57 (patch)
treebfe62d3872c5f031ee40df9488910bd58b0e1b15 /ram
parentExtend tools/pcm.c to allow decoding .pcm to .wav (diff)
parentFix some map text constants (diff)
downloadpokeyellow-04f7f7f506a1dbb877e4678601261e8157fd0e57.tar.gz
pokeyellow-04f7f7f506a1dbb877e4678601261e8157fd0e57.tar.xz
pokeyellow-04f7f7f506a1dbb877e4678601261e8157fd0e57.zip
Merge branch 'master' of https://github.com/pret/pokered
Diffstat (limited to 'ram')
-rw-r--r--ram/hram.asm13
-rw-r--r--ram/wram.asm17
2 files changed, 13 insertions, 17 deletions
diff --git a/ram/hram.asm b/ram/hram.asm
index 0e9a61e1..b396450e 100644
--- a/ram/hram.asm
+++ b/ram/hram.asm
@@ -85,10 +85,10 @@ hSpriteScreenX:: db
hSpriteScreenY:: db
NEXTU
-hFF8F:: db
-hFF90:: db
-hFF91:: db
-hFF92:: db
+hCollidingSpriteOffset:: db
+hCollidingSpriteTempYValue:: db
+hCollidingSpriteTempXValue:: db
+hCollidingSpriteAdjustedDistance:: db
ENDU
hTilePlayerStandingOn:: db
@@ -327,13 +327,10 @@ hItemCounter::
hSavedCoordIndex::
hMissableObjectIndex::
hGymTrashCanRandNumMask::
+hInteractedWithBookshelf::
db
NEXTU
-hFFDB:: db
-hFFDC:: db
-
-NEXTU
hCanceledPrinting:: db
ENDU
diff --git a/ram/wram.asm b/ram/wram.asm
index b67b4749..74d6ae34 100644
--- a/ram/wram.asm
+++ b/ram/wram.asm
@@ -745,10 +745,10 @@ wFilteredBagItemsCount:: db
wSimulatedJoypadStatesIndex:: db
; written to but nothing ever reads it
-wWastedByteCD39:: db
+wUnusedCD39:: db
; written to but nothing ever reads it
-wWastedByteCD3A:: db
+wUnusedCD3A:: db
; mask indicating which real button presses can override simulated ones
; XXX is it ever not 0?
@@ -1061,10 +1061,6 @@ UNION
wcd6d:: ds NAME_BUFFER_LENGTH ; buffer for various data
NEXTU
-wEvosMoves:: ds MAX_EVOLUTIONS * EVOLUTION_SIZE + 1
-wEvosMovesEnd::
-
-NEXTU
ds 4
; temp variable used to print a move's current PP on the status screen
wStatusScreenCurrentPP:: db
@@ -1153,7 +1149,10 @@ wBattleResult:: db
; bit 0: if set, DisplayTextID automatically draws a text box
wAutoTextBoxDrawingControl:: db
-wcf0d:: db ; used with some overworld scripts (not exactly sure what it's used for)
+; used in some overworld scripts to vary scripted movement
+wSavedCoordIndex::
+wOakWalkedToPlayer::
+wNextSafariZoneGateScript:: db
; used in CheckForTilePairCollisions2 to store the tile the player is on
wTilePlayerStandingOn:: db
@@ -2171,8 +2170,8 @@ wMissableObjectFlagsEnd::
ds 7
-; temp copy of SPRITESTATEDATA1_IMAGEINDEX (used for sprite facing/anim)
-wd5cd:: db
+; saved copy of SPRITESTATEDATA1_IMAGEINDEX (used for sprite facing/anim)
+wSavedSpriteImageIndex:: db
; each entry consists of 2 bytes
; * the sprite ID (depending on the current map)